nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

IdleCh

Struct IdleCh 

#[repr(transparent)]
pub struct IdleCh(pub u32);
Idle channel register. This register returns the number of the first idle channel.

Tuple Fields

0: u32

Implementations

Source

impl IdleCh

pub const fn chan(&self) -> u8

Idle channel. Reading the CHAN bits, returns the lowest idle timer channel. The number is positioned such that it can be used as an offset from the MRT base address in order to access the registers for the allocated channel. If all timer channels are running, CHAN = 0xF. See text above for more details.

pub const fn set_chan(&mut self, val: u8)

Idle channel. Reading the CHAN bits, returns the lowest idle timer channel. The number is positioned such that it can be used as an offset from the MRT base address in order to access the registers for the allocated channel. If all timer channels are running, CHAN = 0xF. See text above for more details.