#[repr(transparent)]pub struct Modcfg(pub u32);Expand description
Module Configuration register. This register provides information about this particular MRT instance, and allows choosing an overall mode for the idle channel feature.
Tuple Fields
0: u32Implementations
Sourceimpl Modcfg
impl Modcfg
Sourcepub const fn noc(&self) -> u8
pub const fn noc(&self) -> u8
Identifies the number of channels in this MRT.(4 channels on this device.)
Sourcepub const fn set_noc(&mut self, val: u8)
pub const fn set_noc(&mut self, val: u8)
Identifies the number of channels in this MRT.(4 channels on this device.)
Sourcepub const fn nob(&self) -> u8
pub const fn nob(&self) -> u8
Identifies the number of timer bits in this MRT. (24 bits wide on this device.)
Sourcepub const fn set_nob(&mut self, val: u8)
pub const fn set_nob(&mut self, val: u8)
Identifies the number of timer bits in this MRT. (24 bits wide on this device.)
Sourcepub const fn multitask(&self) -> Multitask
pub const fn multitask(&self) -> Multitask
Selects the operating mode for the INUSE flags and the IDLE_CH register.
Sourcepub const fn set_multitask(&mut self, val: Multitask)
pub const fn set_multitask(&mut self, val: Multitask)
Selects the operating mode for the INUSE flags and the IDLE_CH register.