nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Stat

Struct Stat 

#[repr(transparent)]
pub struct Stat(pub u32);
MRT Status register.

Tuple Fields

0: u32

Implementations

Source

impl Stat

pub const fn intflag(&self) -> bool

Monitors the interrupt flag.

pub const fn set_intflag(&mut self, val: bool)

Monitors the interrupt flag.

pub const fn run(&self) -> Run

Indicates the state of TIMERn. This bit is read-only.

pub const fn set_run(&mut self, val: Run)

Indicates the state of TIMERn. This bit is read-only.

pub const fn inuse(&self) -> bool

Channel In Use flag. Operating details depend on the MULTITASK bit in the MODCFG register, and affects the use of IDLE_CH. See Idle channel register for details of the two operating modes.

pub const fn set_inuse(&mut self, val: bool)

Channel In Use flag. Operating details depend on the MULTITASK bit in the MODCFG register, and affects the use of IDLE_CH. See Idle channel register for details of the two operating modes.