#[repr(transparent)]pub struct IdleCh(pub u32);Expand description
Idle channel register. This register returns the number of the first idle channel.
Tuple Fields
0: u32Implementations
Sourceimpl IdleCh
impl IdleCh
Sourcepub const fn chan(&self) -> u8
pub const fn chan(&self) -> u8
Idle channel. Reading the CHAN bits, returns the lowest idle timer channel. The number is positioned such that it can be used as an offset from the MRT base address in order to access the registers for the allocated channel. If all timer channels are running, CHAN = 0xF. See text above for more details.
Sourcepub const fn set_chan(&mut self, val: u8)
pub const fn set_chan(&mut self, val: u8)
Idle channel. Reading the CHAN bits, returns the lowest idle timer channel. The number is positioned such that it can be used as an offset from the MRT base address in order to access the registers for the allocated channel. If all timer channels are running, CHAN = 0xF. See text above for more details.